#
# spec file for package salt-netapi-client
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
#!BuildRequires: jboss-websocket-1.0-api

Name:           salt-netapi-client
Version:        0.21.0
Release:        230900.1.62.uyuni3
Summary:        Java bindings for the Salt API
License:        MIT
Group:          Development/Libraries/Java
URL:            https://github.com/SUSE/salt-netapi-client
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?rhel} >= 9
BuildRequires:  xmvn-minimal
BuildRequires:  xmvn-tools
%endif
BuildRequires:  xz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(com.google.code.gson:gson) < 2.9.0
BuildRequires:  mvn(javax.websocket:javax.websocket-api)
BuildRequires:  mvn(org.apache.httpcomponents:httpasyncclient)
BuildArch:      noarch
Requires:       java >= 1.8

# This package has been renamed with version 0.7.0
Provides:       saltstack-netapi-client-java == 0.7.0
Obsoletes:      saltstack-netapi-client-java < 0.7.0

%description
Java bindings for the Salt API

%package javadoc
Summary:        API docs for %{name}

%description javadoc
This package contains the API Documentation for %{name}.


%prep
%autosetup -p1 -n "%{name}-%{version}"
find \( -name '*.jar' -o -name '*.class' \) -delete
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin -r :maven-javadoc-plugin

%build
%{mvn_build} -f -- -Dsource=8


%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}


%files -f .mfiles
%doc README.md
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Thu Jan 12 2023 Welder Luz <welder.luz@suse.com>
- Version 0.21.0
  * See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.21.0
- Add transactional_update module
- Improve logging when creating salt exception
* Mon Jun  6 2022 Julio González Gil <jgonzalez@suse.com>
- Declare the LICENSE file as license and not doc
* Sun May  1 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Adapted for Enterprise Linux 9.
* Thu Apr 21 2022 Michael Calmer <mc@suse.com>
- Version 0.20.0
  * See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.20.0
- Remove:
  * 0001-enable-arrays-in-StateApplyResult-name-bsc-1192550.patch
* Thu Apr  7 2022 Vladimir Nadvornik <nadvornik@suse.com>
- Improve the hotfix for bsc#1192550 (bsc#1197449):
  * 0001-enable-arrays-in-StateApplyResult-name-bsc-1192550.patch
* Fri Jan 28 2022 Sasha Andonov <sandonov@suse.com>
- Hotfix (bsc#1192550):
  * 0001-enable-arrays-in-StateApplyResult-name-bsc-1192550.patch
* Fri Nov  5 2021 Johannes Renner <jrenner@suse.com>
- Version 0.19.0
  * See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.19.0
* Mon Oct 12 2020 Johannes Renner <jrenner@suse.com>
- Version 0.18.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.18.0
- Remove:
  * 0001-bring-auth-modules-up-to-date-with-current-salt-docs.patch
  * 0002-cleanup-http-client-after-each-test.patch
* Wed Sep 16 2020 Kevin Walter <kwalter@suse.com>
- Fix text resource usage
- Add:
  * 0002-cleanup-http-client-after-each-test.patch
* Fri Aug 28 2020 Silvio Moioli <moio@suse.com>
- Refresh authentication module list to newer Salt versions
- Add:
  * 0001-bring-auth-modules-up-to-date-with-current-salt-docs.patch
* Thu Feb 27 2020 Abid Mehmood <amehmood@suse.com>
- Version 0.17.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.17.0
- Remove:
  * 0001-handle-random-retcode-field-in-batch-mode.patch
* Tue Apr 30 2019 moio@suse.com
- Add workaround for Salt issue 52762
- Add:
  * 0001-handle-random-retcode-field-in-batch-mode.patch
* Wed Apr 10 2019 Abid Mehmood <amehmood@suse.com>
- Version 0.16.0
  see https://github.com/SUSE/salt-netapi-client/releases/tag/v0.16.0
* Mon Feb 11 2019 jgonzalez@suse.com
- Reenable building for JDK 1.8
* Tue Feb  5 2019 jgonzalez@suse.com
- Version 0.15.1
- Fix javadoc building for JDK11 and later
- Change:
  * build.sh
* Tue Jan 22 2019 jgonzalez@suse.com
- Explicitly require JDK11
* Thu Nov  8 2018 jrenner@suse.com
- Version 0.15.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.15.0
* Wed May  2 2018 jrenner@suse.com
- Version 0.14.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.14.0
- Removed:
  * salt-netapi-client-0.13.0-jdk9.patch
* Tue Nov 21 2017 jgonzalez@suse.com
- Fix build for JDK9
- Add:
  * salt-netapi-client-0.13.0-jdk9.patch
* Tue Sep  5 2017 kwalter@suse.com
- Version 0.13.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.13.0
* Fri Jul 14 2017 jrenner@suse.de
- Version 0.12.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.12.0
- Removed:
  * 0001-Fix-date-format-for-Schedule-bsc-1034465.patch
  * 0002-fix-sending-kwarg-in-payload-in-RunnerCall.patch
* Tue May  2 2017 jrenner@suse.de
- Fix sending kwarg in payload in RunnerCall
- Added:
  * 0002-fix-sending-kwarg-in-payload-in-RunnerCall.patch
* Wed Apr 19 2017 jrenner@suse.de
- Fix date format for Schedule module (bsc#1034465)
- Added:
  * 0001-Fix-date-format-for-Schedule-bsc-1034465.patch
* Tue Mar 28 2017 jrenner@suse.de
- Version 0.11.1
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.11.1
* Thu Feb  2 2017 jrenner@suse.de
- Version 0.10.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.10.0
* Fri Oct 21 2016 jrenner@suse.de
- Version 0.9.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.9.0
* Fri Jun 17 2016 jrenner@suse.de
- Version 0.8.0
* Wed Feb 10 2016 jrenner@suse.de
- Install LICENSE and README.md
* Tue Feb  9 2016 jrenner@suse.com
- Version 0.7.0
  See: https://github.com/SUSE/salt-netapi-client/releases/tag/v0.7.0
- This package has been renamed from 'saltstack-netapi-client-java'
